#!/bin/bash
#
# make a plot of GPS velocity vectors 
#
rm -f map_uv.ps
#
D=blk.lluv
R=-R122.5W/115W/32.7N/38N
U=GPS_u.grd
V=GPS_v.grd
gmtset  FORMAT_GEO_MAP = dddF
gmt select $D $R -fg | awk '{ print($0," 0 ") }' > data.lluvenct
#
#   first make a mask
#
gmt grdlandmask -Gtmp_mask1.grd -R$U -Df
gmt grdmask corner.ll -Gtmp_mask2.grd -R$1 -N1/0/0 
gmt grdmath tmp_mask1.grd tmp_mask2.grd MUL 0 NAN = mask.grd
gmt grdmath $U mask.grd MUL = GPS_u.nc
gmt grdmath $V mask.grd MUL = GPS_v.nc
#
#   make the map
#
gmt pscoast $R -JM6i -P -Glightgray -Ba1f30m -BWSne -K -Df -X0.7i -Wfaint > map_uv.ps
gmt psxy fault_data.gmt -J -R -W.5 -O -V -K >> map_uv.ps
gmt psvelo data.lluvenct -J $R -Se.008i/0.95/8 -A9p -W.2,red -O -K >> map_uv.ps
gmt grdvector GPS_u.nc GPS_v.nc -Ix10/10 -J $R -O -K -Q0.06i+e+n0.06i -Gblue -W.2,blue -S1.i --MAP_VECTOR_SHAPE=0.2 >> map_uv.ps
#
# Place the scale using a geovector of length RATE
#
RATE=50 # This is in mm/yr or km/Myr - change to use another scalebar
echo 121.5W 33N 90 ${RATE}k   | gmt psxy   -R -J -O -K -S=0.06i+e+jc -Gblue -W1p,blue --MAP_VECTOR_SHAPE=0.2 >> map_uv.ps
echo 121.5W 33N ${RATE} mm/yr | gmt pstext -R -J -O -F+f8p+jCB -D0/0.07i >> map_uv.ps

