%
%  Matlab script to check that the Green’s functions satisfy the differential equation
%
% setup variabiles
%
    clear all
    clear classes
    nu=sym('nu');
    x=sym('x');
    y=sym('y');
    r=sqrt(x*x+y*y);
%
%   make the 4 functions
%
    f1=-log(r);
    f2=((y*y)/(r*r)+f1)/2;
    f3=((x*x)/(r*r)+f1)/2;
    f4=-((x*y)/(r*r))/2;
%
%  make the q, p,  and w functions
%
    Q = 2*f1 - (1+nu)*f2;
    P = 2*f1 - (1+nu)*f3;
    W = -(1+nu)*f4;
%
%  make the U and V functions
%
    U = Q + W;
    V = P + W;
%
%  take all the derivatives
%
    Ux = diff(U,'x',1);
    Uxx = diff(Ux,'x',1);
    Uy = diff(U,'y',1);
    Uyy = diff(Uy,'y',1);
    Uxy = diff(Ux,'y',1);
    Uyx = diff(Uy,'x',1);
    Vx = diff(V,'x',1);
    Vxx = diff(Vx,'x',1);
    Vy = diff(V,'y',1);
    Vyy = diff(Vy,'y',1);
    Vxy = diff(Vx,'y',1);
    Vyx = diff(Vy,'x',1);
%
%  make the force equations
%
    fc = (2/(1-nu));
    fnc = (2*nu/(1-nu));
    Fx= fc*Uxx + fnc*Vxy + Uyy + Vxy;
    simplify(Fx)
    Fy= Uxy + Vxx + fnc*Uxy + fc*Vyy;
    simplify(Fy)
